==> libkdegames-18.12.3-1-x86_64.pkg.tar.xz: usr/lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration ""
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::KIOWidgets;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.7.0.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KDEGames.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.7.0.0" )

# Import target "KF5KDEGamesPrivate" for configuration ""
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KDEGamesPrivate.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> libkdegames-19.04.2-1-x86_64.pkg.tar.xz: usr/lib/cmake/KF5KDEGames/KF5KDEGamesLibraryDepends-noconfig.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file.
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5KDEGames" for configuration ""
set_property(TARGET KF5KDEGames APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5KDEGames PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "Qt5::Xml;Qt5::Svg;Qt5::Quick;KF5::Declarative;KF5::NewStuff;KF5::IconThemes;KF5::GuiAddons;KF5::Completion"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.7.0.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KDEGames.so.7"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGames )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGames "${_IMPORT_PREFIX}/lib/libKF5KDEGames.so.7.0.0" )

# Import target "KF5KDEGamesPrivate" for configuration ""
set_property(TARGET KF5KDEGamesPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS NOCONFIG)
set_target_properties(KF5KDEGamesPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_NOCONFIG "KF5::DNSSD;KF5::NewStuff;KF5::Archive"
  IMPORTED_LOCATION_NOCONFIG "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0.0"
  IMPORTED_SONAME_NOCONFIG "libKF5KDEGamesPrivate.so.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5KDEGamesPrivate )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5KDEGamesPrivate "${_IMPORT_PREFIX}/lib/libKF5KDEGamesPrivate.so.1.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
